#
# Copyright 2018 Red Hat, Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
"""Module for aws data generators."""
from nise.generators.ocp.ocp_generator import OCP_NODE_LABEL  # noqa: F401
from nise.generators.ocp.ocp_generator import OCP_POD_USAGE  # noqa: F401
from nise.generators.ocp.ocp_generator import OCP_REPORT_TYPE_TO_COLS  # noqa: F401
from nise.generators.ocp.ocp_generator import OCP_STORAGE_USAGE  # noqa: F401
from nise.generators.ocp.ocp_generator import OCPGenerator  # noqa: F401
